/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Infineon XMC4800 eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define P5_BASE_ADDR  (0x48028500u )
#define P5_OUT        (*(volatile unsigned int*)(P5_BASE_ADDR + 0x00u))
#define P5_OMR        (*(volatile unsigned int*)(P5_BASE_ADDR + 0x04u))
#define P5_IOCR8      (*(volatile unsigned int*)(P5_BASE_ADDR + 0x18u))

#define LED0          (9)  // LED0 P5.9 red
#define LED1          (8)  // LED1 P5.8 red

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  P5_IOCR8 &= 0xFFFF0000u;                        // Reset
  P5_IOCR8 |= 0x00008080u;                        // General-purpose output (push-pull)
  P5_OUT   &= ~( (1u << LED0) | (1u << LED1) );   // Set LED0 and LED1 output to zero
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P5_OUT |= (1u << LED0);
  } else if (Index == 1) {
    P5_OUT |= (1u << LED1);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P5_OUT &= ~(1u << LED0);
  } else if (Index == 1) {
    P5_OUT &= ~(1u << LED1);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P5_OMR |= (1u << LED0) | (1u << (LED0 + 16));
  } else if (Index == 1) {
    P5_OMR |= (1u << LED1) | (1u << (LED1 + 16));
  }
}

/*************************** End of file ****************************/
