/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for NXP MIMXRT1170-EVK
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
//
// The LED implementation is disabled by default since the LED pin is
// also used for EMVSIM1_PD. In order to enable the LED implementation,
// set BSP_ENABLE_LED to 1.
//
#ifndef   BSP_ENABLE_LED
  #define BSP_ENABLE_LED           (0)
#endif

#define LED0_BIT                   (3)  // Green, USER_LED1, D6, high is on
#define LED1_BIT                   (25)  // Green, USER_LED2, D6, high is on

#define SW_MUX_CTL_PAD_GPIO_AD_04  (*(volatile unsigned int*) (0x400E8000u + 0x11Cu))
#define SW_MUX_CTL_PAD_GPIO_AD_26  (*(volatile unsigned int*) (0x400E8000u + 0x174u))

#define GPIO9_BASE_ADDR            (0x40C64000u)
#define GPIO9_DR                   (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x00u))  // Data register
#define GPIO9_GDIR                 (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x04u))  // Data direction register
#define GPIO9_PSR                  (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x08u))  // Pad status register
#define GPIO9_DR_SET               (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x84u))  // Data register set
#define GPIO9_DR_CLEAR             (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x88u))  // Data register clear
#define GPIO9_DR_TOGGLE            (*(volatile unsigned int*) (GPIO9_BASE_ADDR + 0x8Cu))  // Data register toggle


/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
#if (BSP_ENABLE_LED == 1)
  SW_MUX_CTL_PAD_GPIO_AD_04 = ((SW_MUX_CTL_PAD_GPIO_AD_04 & ~(0xFu)) | (10u << 0));  // Switch MUX option to GPIO9_IO03
  SW_MUX_CTL_PAD_GPIO_AD_26 = ((SW_MUX_CTL_PAD_GPIO_AD_26 & ~(0xFu)) | (10u << 0));  // Switch MUX option to GPIO9_IO025
  GPIO9_GDIR |= (1 << LED0_BIT);                                                     // Set GPIO pin to output
  GPIO9_GDIR |= (1 << LED1_BIT);                                                     // Set GPIO pin to output
#endif
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
#if (BSP_ENABLE_LED == 1)
  if (Index == 0) {
    GPIO9_DR_SET |= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIO9_DR_SET |= (1u << LED1_BIT);
  } else {
  }
#else
  BSP_USE_PARA(Index);
#endif
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
#if (BSP_ENABLE_LED == 1)
  if (Index == 0) {
    GPIO9_DR_CLEAR |= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIO9_DR_CLEAR |= (1u << LED1_BIT);
  } else {
  }
#else
  BSP_USE_PARA(Index);
#endif
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
#if (BSP_ENABLE_LED == 1)
  if (Index == 0) {
    GPIO9_DR_TOGGLE |= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIO9_DR_TOGGLE |= (1u << LED1_BIT);
  } else {
  }
#else
  BSP_USE_PARA(Index);
#endif
}

/*************************** End of file ****************************/
