/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for BBC micro:bit eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "nrf.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED_ROW1  (13u)
#define LED_COL1  ( 4u)
#define LED_COL2  ( 5u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  NRF_GPIO->PIN_CNF[LED_ROW1] = (GPIO_PIN_CNF_SENSE_Disabled << GPIO_PIN_CNF_SENSE_Pos)
                              | (GPIO_PIN_CNF_DRIVE_S0S1 << GPIO_PIN_CNF_DRIVE_Pos)
                              | (GPIO_PIN_CNF_PULL_Disabled << GPIO_PIN_CNF_PULL_Pos)
                              | (GPIO_PIN_CNF_INPUT_Connect << GPIO_PIN_CNF_INPUT_Pos)
                              | (GPIO_PIN_CNF_DIR_Output << GPIO_PIN_CNF_DIR_Pos);
  NRF_GPIO->PIN_CNF[LED_COL1] = (GPIO_PIN_CNF_SENSE_Disabled << GPIO_PIN_CNF_SENSE_Pos)
                              | (GPIO_PIN_CNF_DRIVE_S0S1 << GPIO_PIN_CNF_DRIVE_Pos)
                              | (GPIO_PIN_CNF_PULL_Disabled << GPIO_PIN_CNF_PULL_Pos)
                              | (GPIO_PIN_CNF_INPUT_Connect << GPIO_PIN_CNF_INPUT_Pos)
                              | (GPIO_PIN_CNF_DIR_Output << GPIO_PIN_CNF_DIR_Pos);
  NRF_GPIO->PIN_CNF[LED_COL2] = (GPIO_PIN_CNF_SENSE_Disabled << GPIO_PIN_CNF_SENSE_Pos)
                              | (GPIO_PIN_CNF_DRIVE_S0S1 << GPIO_PIN_CNF_DRIVE_Pos)
                              | (GPIO_PIN_CNF_PULL_Disabled << GPIO_PIN_CNF_PULL_Pos)
                              | (GPIO_PIN_CNF_INPUT_Connect << GPIO_PIN_CNF_INPUT_Pos)
                              | (GPIO_PIN_CNF_DIR_Output << GPIO_PIN_CNF_DIR_Pos);
  NRF_GPIO->OUTSET = 1u << LED_ROW1;
  NRF_GPIO->OUTSET = 1u << LED_COL1;
  NRF_GPIO->OUTSET = 1u << LED_COL2;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    NRF_GPIO->OUTSET = 1ul << LED_ROW1;
    NRF_GPIO->OUTCLR = 1ul << LED_COL1;
  } else if (Index == 1) {
    NRF_GPIO->OUTSET = 1ul << LED_ROW1;
    NRF_GPIO->OUTCLR = 1ul << LED_COL2;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    NRF_GPIO->OUTSET = 1ul << LED_ROW1;
    NRF_GPIO->OUTSET = 1ul << LED_COL1;
  } else if (Index == 1) {
    NRF_GPIO->OUTSET = 1ul << LED_ROW1;
    NRF_GPIO->OUTSET = 1ul << LED_COL2;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    NRF_GPIO->OUTSET = (1ul << LED_ROW1);
    NRF_GPIO->OUT   ^= (1ul << LED_COL1);
  } else if (Index == 1) {
    NRF_GPIO->OUTSET = (1ul << LED_ROW1);
    NRF_GPIO->OUT   ^= (1ul << LED_COL2);
  }
}

/****** End Of File *************************************************/
