/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for STM32H7x3I Nucleo board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED1_PIN         (0)  // ARD_D13_LED, LD1, PB0, green, high-active
#define LED2_PIN         (1)  // USER LED2, LD2, PE1, yellow, high-active

#define GPIOB_BASE_ADDR  (0x58020400u)
#define GPIOB_MODER      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_OTYPER     (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x04u))
#define GPIOB_OSPEEDR    (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x08u))
#define GPIOB_PUPDR      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x0Cu))
#define GPIOB_ODR        (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))
#define GPIOB_BSRR       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))

#define GPIOE_BASE_ADDR  (0x58021000u)
#define GPIOE_MODER      (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x00u))
#define GPIOE_OTYPER     (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x04u))
#define GPIOE_OSPEEDR    (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x08u))
#define GPIOE_PUPDR      (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x0Cu))
#define GPIOE_ODR        (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x14u))
#define GPIOE_BSRR       (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x18u))

#define RCC_BASE_ADDR    (0x58024400u)
#define RCC_AHB4ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0xE0u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable GPIO clocks
  //
  RCC_AHB4ENR   |= (0x1u << 1)                  // Enable the GPIOB clock
                |  (0x1u << 4);                 // Enable the GPIOE clock
  //                                            
  // Initialize LED1                            
  //                                            
  GPIOB_MODER   &= ~(0x3u << (LED1_PIN * 2));   // Clear mode register
  GPIOB_MODER   |=  (0x1u << (LED1_PIN * 2));   // Set IO direction to output mode
  GPIOB_OSPEEDR |=  (0x3u << (LED1_PIN * 2));   // Set speed to high frequency
  GPIOB_OTYPER  &= ~(0x1u << (LED1_PIN * 1));   // Set output to push-pull
  GPIOB_PUPDR   &= ~(0x3u << (LED1_PIN * 2));   // Clear the pull-up/pull-down register
  GPIOB_PUPDR   |=  (0x1u << (LED1_PIN * 2));   // Set push-pull to pull-up
  GPIOB_BSRR    |= ((0x1u << 16) << LED1_PIN);  // Turn LED off
  //
  // Initialize LED3
  //
  GPIOE_MODER   &= ~(0x3u << (LED2_PIN * 2));   // Clear mode register
  GPIOE_MODER   |=  (0x1u << (LED2_PIN * 2));   // Set IO direction to output mode
  GPIOE_OSPEEDR |=  (0x3u << (LED2_PIN * 2));   // Set speed to high frequency
  GPIOE_OTYPER  &= ~(0x1u << (LED2_PIN * 1));   // Set output to push-pull
  GPIOE_PUPDR   &= ~(0x3u << (LED2_PIN * 2));   // Clear the pull-up/pull-down register
  GPIOE_PUPDR   |=  (0x1u << (LED2_PIN * 2));   // Set push-pull to pull-up
  GPIOE_BSRR    |= ((0x1u << 16) << LED2_PIN);  // Turn LED off
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOB_BSRR |= (0x1u << LED1_PIN);           // Turn LED on
  } else if (Index == 1) {
    GPIOE_BSRR |= (0x1u << LED2_PIN);           // Turn LED on
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOB_BSRR |= ((0x1u << 16) << LED1_PIN);   // Turn LED off
  } else if (Index == 1) {
    GPIOE_BSRR |= ((0x1u << 16) << LED2_PIN);   // Turn LED off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOB_ODR ^= (0x1u << LED1_PIN);            // Toggle LED
  } else if (Index == 1) {
    GPIOE_ODR ^= (0x1u << LED2_PIN);            // Toggle LED
  }
}

/*************************** End of file ****************************/
