/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for ST STM32L552ZE Nucleo
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED0_BIT                  (5)  // PA5 Green
#define LED1_BIT                  (7)  // PB7 Blue
#define LED2_BIT                  (9)  // PA9 Red

#define RCC_BASE_ADDR             (0x40021000u)
#define RCC_AHB2ENR               (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x4Cu))

#define GPIOA_BASE_ADDR           (0x42020000u)
#define GPIOA_MODER               (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))
#define GPIOA_PUPDR               (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x0Cu))
#define GPIOA_ODR                 (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))
#define GPIOA_BSRR                (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))

#define GPIOB_BASE_ADDR           (0x42020400u)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_PUPDR               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x0Cu))
#define GPIOB_ODR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))
#define GPIOB_BSRR                (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHB2ENR |=  (1u << 0)                // Enable GPIOA clock
              |   (1u << 1);               // Enable GPIOB clock
  GPIOA_MODER &= ~(3u << (LED0_BIT * 2))   // Clear GPIOA pin 5 direction
              &  ~(3u << (LED2_BIT * 2));  // Clear GPIOA pin 9 direction
  GPIOB_MODER &= ~(3u << (LED1_BIT * 2));  // Clear GPIOB pin 7 direction
  GPIOA_MODER |=  (1u << (LED0_BIT * 2))   // Set GPIOA pin 5 to output
              |   (1u << (LED2_BIT * 2));  // Set GPIOA pin 9 to output
  GPIOB_MODER |=  (1u << (LED1_BIT * 2));  // Set GPIOB pin 7 to output
  GPIOA_PUPDR |=  (1u << (LED0_BIT * 2))   // Set GPIOA pin 5 to pull-up
              |   (1u << (LED2_BIT * 2));  // Set GPIOA pin 9 to pull-up
  GPIOB_PUPDR |=  (1u << (LED1_BIT * 2));  // Set GPIOB pin 7 to pull-up
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR |= (1u << (LED0_BIT));         // Switch LED on
  } else if (Index == 1) {
    GPIOB_BSRR |= (1u << (LED1_BIT));         // Switch LED on
  } else if (Index == 2) {
    GPIOA_BSRR |= (1u << (LED2_BIT));         // Switch LED on
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR |= (1u << (LED0_BIT + 16));    // Switch LED off
  } else if (Index == 1) {
    GPIOB_BSRR |= (1u << (LED1_BIT + 16));    // Switch LED off
  } else if (Index == 2) {
    GPIOA_BSRR |= (1u << (LED2_BIT + 16));    // Switch LED off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOA_ODR & (1u << LED0_BIT)) {
      GPIOA_BSRR |= (1u << (LED0_BIT + 16));  // Switch LED off
    } else {
      GPIOA_BSRR |= (1u << LED0_BIT);         // Switch LED on
    }
  } else if (Index == 1) {
    if (GPIOB_ODR & (1u << LED1_BIT)) {
      GPIOB_BSRR |= (1u << (LED1_BIT + 16));  // Switch LED off
    } else {
      GPIOB_BSRR |= (1u << LED1_BIT);         // Switch LED on
    }
  } else if (Index == 2) {
    if (GPIOA_ODR & (1u << LED2_BIT)) {
      GPIOA_BSRR |= (1u << (LED2_BIT + 16));  // Switch LED off
    } else {
      GPIOA_BSRR |= (1u << LED2_BIT);         // Switch LED on
    }
  }
}

/*************************** End of file ****************************/
