/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for EZR32 Leopard Gecko eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "em_device.h"  // Device specific header file, contains CMSIS

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (6)
#define LED1_BIT      (7)
#define LED_PORT      (5) // GPIO port F

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable GPIO
  //
  CMU->HFPERCLKEN0 |= CMU_HFPERCLKEN0_GPIO;
  //
  // Initialize port for LEDs Configure
  // Led 0: GPIO port F, pin 6
  // Led 1: GPIO port F, pin 7
  //
  GPIO->P[LED_PORT].MODEL &= ~(_GPIO_P_MODEL_MODE6_MASK | _GPIO_P_MODEL_MODE7_MASK);    // Reset mode
  GPIO->P[LED_PORT].MODEL |= GPIO_P_MODEL_MODE6_PUSHPULL|  GPIO_P_MODEL_MODE7_PUSHPULL; // Set pins to push-pull output
  //
  // All LEDS off
  //
  GPIO->P[LED_PORT].DOUT &= ~((1uL << LED0_BIT) | (1uL << LED1_BIT));
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO->P[LED_PORT].DOUT |= (1uL << LED0_BIT);  // Switch LED on, active high
  } else if (Index == 1) {
    GPIO->P[LED_PORT].DOUT |= (1uL << LED1_BIT);  // Switch LED on, active high
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO->P[LED_PORT].DOUT &= ~(1uL << LED0_BIT);  // Switch LED off
  } else if (Index == 1) {
    GPIO->P[LED_PORT].DOUT &= ~(1uL << LED1_BIT);  // Switch LED off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIO->P[LED_PORT].DOUT & (1uL << LED0_BIT)) {
      GPIO->P[LED_PORT].DOUT &= ~(1uL << LED0_BIT);   // Switch off LED0
    } else {
      GPIO->P[LED_PORT].DOUT |=  (1uL << LED0_BIT);   // Switch on LED0
    }
  } else if (Index == 1) {
    if (GPIO->P[LED_PORT].DOUT & (1uL << LED1_BIT)) {
      GPIO->P[LED_PORT].DOUT &= ~(1uL << LED1_BIT);   // Switch off LED1
    } else {
      GPIO->P[LED_PORT].DOUT |=  (1uL << LED1_BIT);   // Switch on LED1
    }
  }
}

/****** End Of File *************************************************/
