/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for TI MSP432P411 EXP432P4111 LaunchPad
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT  (0)  // P1.0_LED1, high active
#define LED1_BIT  (0)  // P2.0_RGBLED_RED, high active
#define LED2_BIT  (1)  // P2.1_RGBLED_GREEN, high active
#define LED3_BIT  (2)  // P2.2_RGBLED_BLUE, high active

#define P1OUT     (*(volatile unsigned char*)(0x40004C02u))
#define P2OUT     (*(volatile unsigned char*)(0x40004C03u))
#define P1DIR     (*(volatile unsigned char*)(0x40004C04u))
#define P2DIR     (*(volatile unsigned char*)(0x40004C05u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  P1OUT &= ~(1u << LED0_BIT);    // Initially clear P1.0 (LED0)
  P1DIR |=  (1u << LED0_BIT);    // Configure P1.0 (LED1) as output
  
  P2OUT &= ~((1u << LED1_BIT)
        |    (1u << LED2_BIT)
        |    (1u << LED3_BIT));  // Initially clear P2.0, P2.1, P2.3 (RGBLED_RED, RGBLED_GREEN, RGBLED_BLUE)
  P2DIR |= ((1u << LED1_BIT)
        |   (1u << LED2_BIT)
        |   (1u << LED3_BIT));   // Configure P2.0, P2.1, P2.3 (RGBLED_RED, RGBLED_GREEN, RGBLED_BLUE) as output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P1OUT |= (1u << LED0_BIT);  // Set P1.0 (LED1)
  } else if (Index == 1) {
    P2OUT |= (1u << LED1_BIT);  // Set P2.0 (RGBLED_RED)
  } else if (Index == 2) {
    P2OUT |= (1u << LED2_BIT);  // Set P2.1 (RGBLED_GREEN)
  } else if (Index == 3) {
    P2OUT |= (1u << LED3_BIT);  // Set P2.2 (RGBLED_BLUE)
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P1OUT &= ~(1u << LED0_BIT);  // Clear P1.0 (LED1)
  } else if (Index == 1) {
    P2OUT &= ~(1u << LED1_BIT);  // Clear P2.0 (RGBLED_RED)
  } else if (Index == 2) {
    P2OUT &= ~(1u << LED2_BIT);  // Clear P2.1 (RGBLED_GREEN)
  } else if (Index == 3) {
    P2OUT &= ~(1u << LED3_BIT);  // Clear P2.2 (RGBLED_BLUE)
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P1OUT ^= (1u << LED0_BIT);  // Toggle P1.0 (LED1)
  } else if (Index == 1) {
    P2OUT ^= (1u << LED1_BIT);  // Toggle P2.0 (RGBLED_RED)
  } else if (Index == 2) {
    P2OUT ^= (1u << LED2_BIT);  // Toggle P2.1 (RGBLED_GREEN)
  } else if (Index == 3) {
    P2OUT ^= (1u << LED3_BIT);  // Toggle P2.2 (RGBLED_BLUE)
  }
}

/*************************** End of file ****************************/
